declare const service: {
    name: string;
    slug: string;
    description: string;
    hasPublicEndpoints: boolean;
    endpoints: ({
        id: string;
        title: string;
        sectionTitle: string;
        method: string;
        path: string;
        description: string;
        pathParams: never[];
        queryParams: {
            name: string;
            type: string;
            description: string;
            required: boolean;
        }[];
        requestBody: {
            description: string;
            fields: {
                schema: import("zod").ZodObject<{
                    projectId: import("zod").ZodOptional<import("zod").ZodString>;
                    runtime: import("zod").ZodOptional<import("zod").ZodString>;
                    runtimeId: import("zod").ZodOptional<import("zod").ZodString>;
                    name: import("zod").ZodOptional<import("zod").ZodString>;
                    description: import("zod").ZodOptional<import("zod").ZodString>;
                    resources: import("zod").ZodOptional<import("zod").ZodObject<{
                        memory: import("zod").ZodOptional<import("zod").ZodString>;
                        cpu: import("zod").ZodOptional<import("zod").ZodString>;
                        disk: import("zod").ZodOptional<import("zod").ZodString>;
                    }, import("zod/v4/core").$strip>>;
                    env: import("zod").ZodOptional<import("zod").ZodRecord<import("zod").ZodString, import("zod").ZodString>>;
                    network: import("zod").ZodOptional<import("zod").ZodObject<{
                        enabled: import("zod").ZodOptional<import("zod").ZodBoolean>;
                        port: import("zod").ZodOptional<import("zod").ZodNumber>;
                    }, import("zod/v4/core").$strip>>;
                    stream: import("zod").ZodOptional<import("zod").ZodObject<{
                        stdout: import("zod").ZodOptional<import("zod").ZodString>;
                        stderr: import("zod").ZodOptional<import("zod").ZodString>;
                        stdin: import("zod").ZodOptional<import("zod").ZodString>;
                        timestamps: import("zod").ZodOptional<import("zod").ZodBoolean>;
                    }, import("zod/v4/core").$strip>>;
                    timeout: import("zod").ZodOptional<import("zod").ZodObject<{
                        idle: import("zod").ZodOptional<import("zod").ZodString>;
                        execution: import("zod").ZodOptional<import("zod").ZodString>;
                        paused: import("zod").ZodOptional<import("zod").ZodString>;
                    }, import("zod/v4/core").$strip>>;
                    command: import("zod").ZodOptional<import("zod").ZodObject<{
                        exec: import("zod").ZodArray<import("zod").ZodString>;
                        files: import("zod").ZodOptional<import("zod").ZodArray<import("zod").ZodObject<{
                            path: import("zod").ZodString;
                            content: import("zod").ZodString;
                        }, import("zod/v4/core").$strip>>>;
                        mode: import("zod").ZodOptional<import("zod").ZodEnum<{
                            oneshot: "oneshot";
                            interactive: "interactive";
                        }>>;
                    }, import("zod/v4/core").$strip>>;
                    files: import("zod").ZodOptional<import("zod").ZodArray<import("zod").ZodObject<{
                        path: import("zod").ZodString;
                        content: import("zod").ZodString;
                    }, import("zod/v4/core").$strip>>>;
                    snapshot: import("zod").ZodOptional<import("zod").ZodString>;
                    dependencies: import("zod").ZodOptional<import("zod").ZodArray<import("zod").ZodString>>;
                    packages: import("zod").ZodOptional<import("zod").ZodArray<import("zod").ZodString>>;
                    metadata: import("zod").ZodOptional<import("zod").ZodRecord<import("zod").ZodString, import("zod").ZodUnknown>>;
                    scopes: import("zod").ZodOptional<import("zod").ZodArray<import("zod").ZodString>>;
                    disableSnapshots: import("zod").ZodOptional<import("zod").ZodBoolean>;
                }, import("zod/v4/core").$strip>;
                omit?: undefined;
            };
        };
        responseDescription: string;
        responseFields: {
            schema: import("zod").ZodObject<{
                sandboxId: import("zod").ZodString;
                status: import("zod").ZodEnum<{
                    creating: "creating";
                    idle: "idle";
                    running: "running";
                    paused: "paused";
                    stopping: "stopping";
                    suspended: "suspended";
                    terminated: "terminated";
                    failed: "failed";
                }>;
                executionId: import("zod").ZodOptional<import("zod").ZodString>;
                url: import("zod").ZodOptional<import("zod").ZodString>;
                stdoutStreamId: import("zod").ZodOptional<import("zod").ZodString>;
                stdoutStreamUrl: import("zod").ZodOptional<import("zod").ZodString>;
                stderrStreamId: import("zod").ZodOptional<import("zod").ZodString>;
                stderrStreamUrl: import("zod").ZodOptional<import("zod").ZodString>;
                auditStreamId: import("zod").ZodOptional<import("zod").ZodString>;
                auditStreamUrl: import("zod").ZodOptional<import("zod").ZodString>;
            }, import("zod/v4/core").$strip>;
            stripRequired?: undefined;
        };
        statuses: {
            code: number;
            description: string;
        }[];
        examplePath: string;
        exampleBody: {
            name: string;
            runtime: string;
            resources: {
                memory: number;
            };
            env: {
                NODE_ENV: string;
                OLD_VAR?: undefined;
            };
            command?: undefined;
            files?: undefined;
            path?: undefined;
            recursive?: undefined;
            tag?: undefined;
            sizeBytes?: undefined;
            fileCount?: undefined;
        };
        exampleHeaders?: undefined;
    } | {
        id: string;
        title: string;
        sectionTitle: string;
        method: string;
        path: string;
        description: string;
        pathParams: never[];
        queryParams: {
            name: string;
            type: string;
            description: string;
            required: boolean;
        }[];
        requestBody: null;
        responseDescription: string;
        responseFields: {
            schema: import("zod").ZodDiscriminatedUnion<[import("zod").ZodObject<{
                success: import("zod").ZodLiteral<false>;
                message: import("zod").ZodString;
                code: import("zod").ZodOptional<import("zod").ZodString>;
            }, import("zod/v4/core").$strip>, import("zod").ZodObject<{
                success: import("zod").ZodLiteral<true>;
                data: import("zod").ZodObject<{
                    sandboxes: import("zod").ZodArray<import("zod").ZodObject<{
                        sandboxId: import("zod").ZodString;
                        identifier: import("zod").ZodOptional<import("zod").ZodString>;
                        name: import("zod").ZodOptional<import("zod").ZodString>;
                        description: import("zod").ZodOptional<import("zod").ZodString>;
                        status: import("zod").ZodEnum<{
                            creating: "creating";
                            idle: "idle";
                            running: "running";
                            paused: "paused";
                            stopping: "stopping";
                            suspended: "suspended";
                            terminated: "terminated";
                            failed: "failed";
                            deleted: "deleted";
                        }>;
                        mode: import("zod").ZodOptional<import("zod").ZodString>;
                        createdAt: import("zod").ZodString;
                        region: import("zod").ZodOptional<import("zod").ZodString>;
                        runtime: import("zod").ZodOptional<import("zod").ZodObject<{
                            id: import("zod").ZodString;
                            name: import("zod").ZodString;
                            iconUrl: import("zod").ZodOptional<import("zod").ZodString>;
                            brandColor: import("zod").ZodOptional<import("zod").ZodString>;
                            tags: import("zod").ZodOptional<import("zod").ZodArray<import("zod").ZodString>>;
                        }, import("zod/v4/core").$strip>>;
                        snapshot: import("zod").ZodOptional<import("zod").ZodUnion<readonly [import("zod").ZodObject<{
                            id: import("zod").ZodString;
                            name: import("zod").ZodOptional<import("zod").ZodString>;
                            tag: import("zod").ZodOptional<import("zod").ZodString>;
                            fullName: import("zod").ZodOptional<import("zod").ZodString>;
                            public: import("zod").ZodLiteral<true>;
                            org: import("zod").ZodObject<{
                                id: import("zod").ZodString;
                                name: import("zod").ZodString;
                                slug: import("zod").ZodOptional<import("zod").ZodString>;
                            }, import("zod/v4/core").$strip>;
                        }, import("zod/v4/core").$strip>, import("zod").ZodObject<{
                            id: import("zod").ZodString;
                            name: import("zod").ZodOptional<import("zod").ZodString>;
                            tag: import("zod").ZodOptional<import("zod").ZodString>;
                            fullName: import("zod").ZodOptional<import("zod").ZodString>;
                            public: import("zod").ZodLiteral<false>;
                            user: import("zod").ZodObject<{
                                id: import("zod").ZodString;
                                firstName: import("zod").ZodOptional<import("zod").ZodString>;
                                lastName: import("zod").ZodOptional<import("zod").ZodString>;
                            }, import("zod/v4/core").$strip>;
                        }, import("zod/v4/core").$strip>]>>;
                        executions: import("zod").ZodNumber;
                        stdoutStreamUrl: import("zod").ZodOptional<import("zod").ZodString>;
                        stderrStreamUrl: import("zod").ZodOptional<import("zod").ZodString>;
                        auditStreamId: import("zod").ZodOptional<import("zod").ZodString>;
                        auditStreamUrl: import("zod").ZodOptional<import("zod").ZodString>;
                        networkEnabled: import("zod").ZodOptional<import("zod").ZodBoolean>;
                        networkPort: import("zod").ZodOptional<import("zod").ZodNumber>;
                        url: import("zod").ZodOptional<import("zod").ZodString>;
                        org: import("zod").ZodObject<{
                            id: import("zod").ZodString;
                            name: import("zod").ZodString;
                        }, import("zod/v4/core").$strip>;
                        timeout: import("zod").ZodOptional<import("zod").ZodObject<{
                            idle: import("zod").ZodOptional<import("zod").ZodString>;
                            execution: import("zod").ZodOptional<import("zod").ZodString>;
                            paused: import("zod").ZodOptional<import("zod").ZodString>;
                        }, import("zod/v4/core").$strip>>;
                        command: import("zod").ZodOptional<import("zod").ZodObject<{
                            exec: import("zod").ZodArray<import("zod").ZodString>;
                            mode: import("zod").ZodOptional<import("zod").ZodEnum<{
                                oneshot: "oneshot";
                                interactive: "interactive";
                            }>>;
                        }, import("zod/v4/core").$strip>>;
                    }, import("zod/v4/core").$strip>>;
                    total: import("zod").ZodNumber;
                }, import("zod/v4/core").$strip>;
            }, import("zod/v4/core").$strip>], "success">;
            stripRequired?: undefined;
        };
        statuses: {
            code: number;
            description: string;
        }[];
        examplePath: string;
        exampleBody?: undefined;
        exampleHeaders?: undefined;
    } | {
        id: string;
        title: string;
        sectionTitle: string;
        method: string;
        path: string;
        description: string;
        pathParams: {
            name: string;
            type: string;
            description: string;
            required: boolean;
        }[];
        queryParams: {
            name: string;
            type: string;
            description: string;
            required: boolean;
        }[];
        requestBody: null;
        responseDescription: string;
        statuses: {
            code: number;
            description: string;
        }[];
        examplePath: string;
        responseFields?: undefined;
        exampleBody?: undefined;
        exampleHeaders?: undefined;
    } | {
        id: string;
        title: string;
        sectionTitle: string;
        method: string;
        path: string;
        description: string;
        pathParams: {
            name: string;
            type: string;
            description: string;
            required: boolean;
        }[];
        queryParams: {
            name: string;
            type: string;
            description: string;
            required: boolean;
        }[];
        requestBody: null;
        responseDescription: string;
        responseFields: {
            schema: import("zod").ZodObject<{
                sandboxId: import("zod").ZodString;
                status: import("zod").ZodString;
                exitCode: import("zod").ZodOptional<import("zod").ZodNumber>;
            }, import("zod/v4/core").$strip>;
            stripRequired: boolean;
        };
        statuses: {
            code: number;
            description: string;
        }[];
        examplePath: string;
        exampleBody?: undefined;
        exampleHeaders?: undefined;
    } | {
        id: string;
        title: string;
        sectionTitle: string;
        method: string;
        path: string;
        description: string;
        pathParams: {
            name: string;
            type: string;
            description: string;
            required: boolean;
        }[];
        queryParams: {
            name: string;
            type: string;
            description: string;
            required: boolean;
        }[];
        requestBody: {
            description: string;
            fields: {
                schema: import("zod").ZodObject<{
                    env: import("zod").ZodRecord<import("zod").ZodString, import("zod").ZodNullable<import("zod").ZodString>>;
                }, import("zod/v4/core").$strip>;
                omit?: undefined;
            };
        };
        responseDescription: string;
        responseFields: {
            schema: import("zod").ZodObject<{
                env: import("zod").ZodRecord<import("zod").ZodString, import("zod").ZodString>;
            }, import("zod/v4/core").$strip>;
            stripRequired: boolean;
        };
        statuses: {
            code: number;
            description: string;
        }[];
        examplePath: string;
        exampleBody: {
            env: {
                NODE_ENV: string;
                OLD_VAR: null;
            };
            name?: undefined;
            runtime?: undefined;
            resources?: undefined;
            command?: undefined;
            files?: undefined;
            path?: undefined;
            recursive?: undefined;
            tag?: undefined;
            sizeBytes?: undefined;
            fileCount?: undefined;
        };
        exampleHeaders?: undefined;
    } | {
        id: string;
        title: string;
        sectionTitle: string;
        method: string;
        path: string;
        description: string;
        pathParams: {
            name: string;
            type: string;
            description: string;
            required: boolean;
        }[];
        queryParams: {
            name: string;
            type: string;
            description: string;
            required: boolean;
        }[];
        requestBody: {
            description: string;
            fields: {
                schema: import("zod").ZodObject<{
                    command: import("zod").ZodArray<import("zod").ZodString>;
                    files: import("zod").ZodOptional<import("zod").ZodArray<import("zod").ZodObject<{
                        path: import("zod").ZodString;
                        content: import("zod").ZodString;
                    }, import("zod/v4/core").$strip>>>;
                    timeout: import("zod").ZodOptional<import("zod").ZodString>;
                    stream: import("zod").ZodOptional<import("zod").ZodObject<{
                        stdout: import("zod").ZodOptional<import("zod").ZodString>;
                        stderr: import("zod").ZodOptional<import("zod").ZodString>;
                        timestamps: import("zod").ZodOptional<import("zod").ZodBoolean>;
                    }, import("zod/v4/core").$strip>>;
                }, import("zod/v4/core").$strip>;
                omit?: undefined;
            };
        };
        responseDescription: string;
        responseFields: {
            schema: import("zod").ZodObject<{
                executionId: import("zod").ZodString;
                status: import("zod").ZodEnum<{
                    running: "running";
                    failed: "failed";
                    queued: "queued";
                    completed: "completed";
                    timeout: "timeout";
                    cancelled: "cancelled";
                }>;
                exitCode: import("zod").ZodOptional<import("zod").ZodNumber>;
                durationMs: import("zod").ZodOptional<import("zod").ZodNumber>;
                stdoutStreamUrl: import("zod").ZodOptional<import("zod").ZodString>;
                stderrStreamUrl: import("zod").ZodOptional<import("zod").ZodString>;
                outputTruncated: import("zod").ZodOptional<import("zod").ZodBoolean>;
            }, import("zod/v4/core").$strip>;
            stripRequired?: undefined;
        };
        statuses: {
            code: number;
            description: string;
        }[];
        examplePath: string;
        exampleBody: {
            command: string[];
            name?: undefined;
            runtime?: undefined;
            resources?: undefined;
            env?: undefined;
            files?: undefined;
            path?: undefined;
            recursive?: undefined;
            tag?: undefined;
            sizeBytes?: undefined;
            fileCount?: undefined;
        };
        exampleHeaders?: undefined;
    } | {
        id: string;
        title: string;
        sectionTitle: string;
        method: string;
        path: string;
        description: string;
        pathParams: {
            name: string;
            type: string;
            description: string;
            required: boolean;
        }[];
        queryParams: {
            name: string;
            type: string;
            description: string;
            required: boolean;
        }[];
        requestBody: null;
        responseDescription: string;
        responseFields: {
            schema: import("zod").ZodObject<{
                events: import("zod").ZodArray<import("zod").ZodObject<{
                    eventId: import("zod").ZodString;
                    sandboxId: import("zod").ZodString;
                    type: import("zod").ZodString;
                    event: import("zod").ZodRecord<import("zod").ZodString, import("zod").ZodUnknown>;
                    createdAt: import("zod").ZodString;
                }, import("zod/v4/core").$strip>>;
            }, import("zod/v4/core").$strip>;
            stripRequired?: undefined;
        };
        statuses: {
            code: number;
            description: string;
        }[];
        examplePath: string;
        exampleBody?: undefined;
        exampleHeaders?: undefined;
    } | {
        id: string;
        title: string;
        sectionTitle: string;
        method: string;
        path: string;
        description: string;
        pathParams: {
            name: string;
            type: string;
            description: string;
            required: boolean;
        }[];
        queryParams: {
            name: string;
            type: string;
            description: string;
            required: boolean;
        }[];
        requestBody: {
            description: string;
            fields: {
                schema: import("zod").ZodObject<{
                    files: import("zod").ZodArray<import("zod").ZodObject<{
                        path: import("zod").ZodString;
                        content: import("zod").ZodString;
                    }, import("zod/v4/core").$strip>>;
                }, import("zod/v4/core").$strip>;
                omit?: undefined;
            };
        };
        responseDescription: string;
        responseFields: {
            schema: import("zod").ZodObject<{
                filesWritten: import("zod").ZodNumber;
            }, import("zod/v4/core").$strip>;
            stripRequired?: undefined;
        };
        statuses: {
            code: number;
            description: string;
        }[];
        examplePath: string;
        exampleBody: {
            files: {
                path: string;
                content: string;
            }[];
            name?: undefined;
            runtime?: undefined;
            resources?: undefined;
            env?: undefined;
            command?: undefined;
            path?: undefined;
            recursive?: undefined;
            tag?: undefined;
            sizeBytes?: undefined;
            fileCount?: undefined;
        };
        exampleHeaders?: undefined;
    } | {
        id: string;
        title: string;
        sectionTitle: string;
        method: string;
        path: string;
        description: string;
        pathParams: {
            name: string;
            type: string;
            description: string;
            required: boolean;
        }[];
        queryParams: {
            name: string;
            type: string;
            description: string;
            required: boolean;
        }[];
        requestBody: {
            description: string;
            fields: {
                schema: import("zod").ZodObject<{
                    path: import("zod").ZodString;
                    recursive: import("zod").ZodOptional<import("zod").ZodBoolean>;
                }, import("zod/v4/core").$strip>;
                omit?: undefined;
            };
        };
        responseDescription: string;
        statuses: {
            code: number;
            description: string;
        }[];
        examplePath: string;
        exampleBody: {
            path: string;
            recursive: boolean;
            name?: undefined;
            runtime?: undefined;
            resources?: undefined;
            env?: undefined;
            command?: undefined;
            files?: undefined;
            tag?: undefined;
            sizeBytes?: undefined;
            fileCount?: undefined;
        };
        responseFields?: undefined;
        exampleHeaders?: undefined;
    } | {
        id: string;
        title: string;
        sectionTitle: string;
        method: string;
        path: string;
        description: string;
        pathParams: {
            name: string;
            type: string;
            description: string;
            required: boolean;
        }[];
        queryParams: {
            name: string;
            type: string;
            description: string;
            required: boolean;
        }[];
        requestBody: {
            description: string;
            fields: {
                schema: import("zod").ZodObject<{
                    path: import("zod").ZodString;
                }, import("zod/v4/core").$strip>;
                omit?: undefined;
            };
        };
        responseDescription: string;
        statuses: {
            code: number;
            description: string;
        }[];
        examplePath: string;
        exampleBody: {
            path: string;
            name?: undefined;
            runtime?: undefined;
            resources?: undefined;
            env?: undefined;
            command?: undefined;
            files?: undefined;
            recursive?: undefined;
            tag?: undefined;
            sizeBytes?: undefined;
            fileCount?: undefined;
        };
        responseFields?: undefined;
        exampleHeaders?: undefined;
    } | {
        id: string;
        title: string;
        sectionTitle: string;
        method: string;
        path: string;
        description: string;
        pathParams: {
            name: string;
            type: string;
            description: string;
            required: boolean;
        }[];
        queryParams: {
            name: string;
            type: string;
            description: string;
            required: boolean;
        }[];
        requestBody: null;
        responseDescription: string;
        responseFields: {
            schema: import("zod").ZodObject<{
                files: import("zod").ZodArray<import("zod").ZodObject<{
                    path: import("zod").ZodString;
                    size: import("zod").ZodNumber;
                    isDir: import("zod").ZodBoolean;
                    isSymlink: import("zod").ZodOptional<import("zod").ZodBoolean>;
                    linkTarget: import("zod").ZodOptional<import("zod").ZodString>;
                    mode: import("zod").ZodString;
                    modTime: import("zod").ZodString;
                }, import("zod/v4/core").$strip>>;
            }, import("zod/v4/core").$strip>;
            stripRequired?: undefined;
        };
        statuses: {
            code: number;
            description: string;
        }[];
        examplePath: string;
        exampleBody?: undefined;
        exampleHeaders?: undefined;
    } | {
        id: string;
        title: string;
        sectionTitle: string;
        method: string;
        path: string;
        description: string;
        pathParams: {
            name: string;
            type: string;
            description: string;
            required: boolean;
        }[];
        queryParams: {
            name: string;
            type: string;
            description: string;
            required: boolean;
        }[];
        requestBody: null;
        responseDescription: string;
        statuses: {
            code: number;
            description: string;
        }[];
        examplePath: string;
        exampleHeaders: {
            'Content-Type': string;
        };
        exampleBody: string;
        responseFields?: undefined;
    } | {
        id: string;
        title: string;
        sectionTitle: string;
        method: string;
        path: string;
        description: string;
        pathParams: {
            name: string;
            type: string;
            description: string;
            required: boolean;
        }[];
        queryParams: {
            name: string;
            type: string;
            description: string;
            required: boolean;
        }[];
        requestBody: {
            description: string;
            fields: {
                schema: import("zod").ZodObject<{
                    description: import("zod").ZodOptional<import("zod").ZodString>;
                    name: import("zod").ZodOptional<import("zod").ZodString>;
                    tag: import("zod").ZodOptional<import("zod").ZodString>;
                    public: import("zod").ZodOptional<import("zod").ZodBoolean>;
                }, import("zod/v4/core").$strip>;
                omit?: undefined;
            };
        };
        responseDescription: string;
        statuses: {
            code: number;
            description: string;
        }[];
        examplePath: string;
        exampleBody: {
            name: string;
            tag: string;
            runtime?: undefined;
            resources?: undefined;
            env?: undefined;
            command?: undefined;
            files?: undefined;
            path?: undefined;
            recursive?: undefined;
            sizeBytes?: undefined;
            fileCount?: undefined;
        };
        responseFields?: undefined;
        exampleHeaders?: undefined;
    } | {
        id: string;
        title: string;
        sectionTitle: string;
        method: string;
        path: string;
        description: string;
        pathParams: never[];
        queryParams: {
            name: string;
            type: string;
            description: string;
            required: boolean;
        }[];
        requestBody: null;
        responseDescription: string;
        responseFields: {
            schema: import("zod").ZodDiscriminatedUnion<[import("zod").ZodObject<{
                success: import("zod").ZodLiteral<false>;
                message: import("zod").ZodString;
                code: import("zod").ZodOptional<import("zod").ZodString>;
            }, import("zod/v4/core").$strip>, import("zod").ZodObject<{
                success: import("zod").ZodLiteral<true>;
                data: import("zod").ZodObject<{
                    snapshots: import("zod").ZodArray<import("zod").ZodObject<{
                        snapshotId: import("zod").ZodString;
                        runtimeId: import("zod").ZodOptional<import("zod").ZodNullable<import("zod").ZodString>>;
                        name: import("zod").ZodString;
                        fullName: import("zod").ZodOptional<import("zod").ZodString>;
                        description: import("zod").ZodOptional<import("zod").ZodNullable<import("zod").ZodString>>;
                        message: import("zod").ZodOptional<import("zod").ZodNullable<import("zod").ZodString>>;
                        tag: import("zod").ZodOptional<import("zod").ZodNullable<import("zod").ZodString>>;
                        sizeBytes: import("zod").ZodNumber;
                        fileCount: import("zod").ZodNumber;
                        parentSnapshotId: import("zod").ZodOptional<import("zod").ZodNullable<import("zod").ZodString>>;
                        public: import("zod").ZodOptional<import("zod").ZodBoolean>;
                        orgName: import("zod").ZodOptional<import("zod").ZodString>;
                        orgSlug: import("zod").ZodOptional<import("zod").ZodString>;
                        org: import("zod").ZodOptional<import("zod").ZodNullable<import("zod").ZodObject<{
                            id: import("zod").ZodString;
                            name: import("zod").ZodString;
                            slug: import("zod").ZodOptional<import("zod").ZodNullable<import("zod").ZodString>>;
                        }, import("zod/v4/core").$strip>>>;
                        user: import("zod").ZodOptional<import("zod").ZodNullable<import("zod").ZodObject<{
                            id: import("zod").ZodString;
                            firstName: import("zod").ZodOptional<import("zod").ZodNullable<import("zod").ZodString>>;
                            lastName: import("zod").ZodOptional<import("zod").ZodNullable<import("zod").ZodString>>;
                        }, import("zod/v4/core").$strip>>>;
                        createdAt: import("zod").ZodString;
                        downloadUrl: import("zod").ZodOptional<import("zod").ZodString>;
                        files: import("zod").ZodOptional<import("zod").ZodNullable<import("zod").ZodArray<import("zod").ZodObject<{
                            path: import("zod").ZodString;
                            size: import("zod").ZodNumber;
                            sha256: import("zod").ZodString;
                            contentType: import("zod").ZodString;
                            mode: import("zod").ZodNumber;
                        }, import("zod/v4/core").$strip>>>>;
                        userMetadata: import("zod").ZodOptional<import("zod").ZodNullable<import("zod").ZodRecord<import("zod").ZodString, import("zod").ZodString>>>;
                    }, import("zod/v4/core").$strip>>;
                    total: import("zod").ZodNumber;
                }, import("zod/v4/core").$strip>;
            }, import("zod/v4/core").$strip>], "success">;
            stripRequired?: undefined;
        };
        statuses: {
            code: number;
            description: string;
        }[];
        examplePath: string;
        exampleBody?: undefined;
        exampleHeaders?: undefined;
    } | {
        id: string;
        title: string;
        sectionTitle: string;
        method: string;
        path: string;
        description: string;
        pathParams: {
            name: string;
            type: string;
            description: string;
            required: boolean;
        }[];
        queryParams: {
            name: string;
            type: string;
            description: string;
            required: boolean;
        }[];
        requestBody: {
            description: string;
            fields: {
                schema: import("zod").ZodObject<{
                    tag: import("zod").ZodNullable<import("zod").ZodString>;
                }, import("zod/v4/core").$strip>;
                omit?: undefined;
            };
        };
        responseDescription: string;
        statuses: {
            code: number;
            description: string;
        }[];
        examplePath: string;
        exampleBody: {
            tag: string;
            name?: undefined;
            runtime?: undefined;
            resources?: undefined;
            env?: undefined;
            command?: undefined;
            files?: undefined;
            path?: undefined;
            recursive?: undefined;
            sizeBytes?: undefined;
            fileCount?: undefined;
        };
        responseFields?: undefined;
        exampleHeaders?: undefined;
    } | {
        id: string;
        title: string;
        sectionTitle: string;
        method: string;
        path: string;
        description: string;
        pathParams: never[];
        queryParams: {
            name: string;
            type: string;
            description: string;
            required: boolean;
        }[];
        requestBody: null;
        responseDescription: string;
        responseFields: {
            schema: import("zod").ZodDiscriminatedUnion<[import("zod").ZodObject<{
                success: import("zod").ZodLiteral<false>;
                message: import("zod").ZodString;
                code: import("zod").ZodOptional<import("zod").ZodString>;
            }, import("zod/v4/core").$strip>, import("zod").ZodObject<{
                success: import("zod").ZodLiteral<true>;
                data: import("zod").ZodObject<{
                    snapshots: import("zod").ZodArray<import("zod").ZodObject<{
                        snapshotId: import("zod").ZodString;
                        runtimeId: import("zod").ZodOptional<import("zod").ZodNullable<import("zod").ZodString>>;
                        name: import("zod").ZodString;
                        fullName: import("zod").ZodOptional<import("zod").ZodString>;
                        description: import("zod").ZodOptional<import("zod").ZodNullable<import("zod").ZodString>>;
                        message: import("zod").ZodOptional<import("zod").ZodNullable<import("zod").ZodString>>;
                        tag: import("zod").ZodOptional<import("zod").ZodNullable<import("zod").ZodString>>;
                        sizeBytes: import("zod").ZodNumber;
                        fileCount: import("zod").ZodNumber;
                        parentSnapshotId: import("zod").ZodOptional<import("zod").ZodNullable<import("zod").ZodString>>;
                        public: import("zod").ZodOptional<import("zod").ZodBoolean>;
                        orgName: import("zod").ZodOptional<import("zod").ZodString>;
                        orgSlug: import("zod").ZodOptional<import("zod").ZodString>;
                        org: import("zod").ZodOptional<import("zod").ZodNullable<import("zod").ZodObject<{
                            id: import("zod").ZodString;
                            name: import("zod").ZodString;
                            slug: import("zod").ZodOptional<import("zod").ZodNullable<import("zod").ZodString>>;
                        }, import("zod/v4/core").$strip>>>;
                        user: import("zod").ZodOptional<import("zod").ZodNullable<import("zod").ZodObject<{
                            id: import("zod").ZodString;
                            firstName: import("zod").ZodOptional<import("zod").ZodNullable<import("zod").ZodString>>;
                            lastName: import("zod").ZodOptional<import("zod").ZodNullable<import("zod").ZodString>>;
                        }, import("zod/v4/core").$strip>>>;
                        createdAt: import("zod").ZodString;
                        downloadUrl: import("zod").ZodOptional<import("zod").ZodString>;
                        files: import("zod").ZodOptional<import("zod").ZodNullable<import("zod").ZodArray<import("zod").ZodObject<{
                            path: import("zod").ZodString;
                            size: import("zod").ZodNumber;
                            sha256: import("zod").ZodString;
                            contentType: import("zod").ZodString;
                            mode: import("zod").ZodNumber;
                        }, import("zod/v4/core").$strip>>>>;
                        userMetadata: import("zod").ZodOptional<import("zod").ZodNullable<import("zod").ZodRecord<import("zod").ZodString, import("zod").ZodString>>>;
                    }, import("zod/v4/core").$strip>>;
                    total: import("zod").ZodNumber;
                }, import("zod/v4/core").$strip>;
            }, import("zod/v4/core").$strip>], "success">;
            stripRequired: boolean;
        };
        statuses: {
            code: number;
            description: string;
        }[];
        examplePath: string;
        exampleBody?: undefined;
        exampleHeaders?: undefined;
    } | {
        id: string;
        title: string;
        sectionTitle: string;
        method: string;
        path: string;
        description: string;
        pathParams: never[];
        queryParams: {
            name: string;
            type: string;
            description: string;
            required: boolean;
        }[];
        requestBody: {
            description: string;
            fields: {
                schema: import("zod").ZodObject<{
                    runtime: import("zod").ZodString;
                    name: import("zod").ZodOptional<import("zod").ZodString>;
                    tag: import("zod").ZodOptional<import("zod").ZodString>;
                    description: import("zod").ZodOptional<import("zod").ZodString>;
                    contentHash: import("zod").ZodOptional<import("zod").ZodString>;
                    force: import("zod").ZodOptional<import("zod").ZodBoolean>;
                    encrypt: import("zod").ZodOptional<import("zod").ZodBoolean>;
                    public: import("zod").ZodOptional<import("zod").ZodBoolean>;
                }, import("zod/v4/core").$strip>;
                omit?: undefined;
            };
        };
        responseDescription: string;
        responseFields: {
            schema: import("zod").ZodObject<{
                snapshotId: import("zod").ZodOptional<import("zod").ZodString>;
                uploadUrl: import("zod").ZodOptional<import("zod").ZodString>;
                publicKey: import("zod").ZodOptional<import("zod").ZodString>;
                unchanged: import("zod").ZodOptional<import("zod").ZodBoolean>;
                existingId: import("zod").ZodOptional<import("zod").ZodString>;
                existingName: import("zod").ZodOptional<import("zod").ZodString>;
                existingTag: import("zod").ZodOptional<import("zod").ZodString>;
            }, import("zod/v4/core").$strip>;
            stripRequired: boolean;
        };
        statuses: {
            code: number;
            description: string;
        }[];
        examplePath: string;
        exampleBody: {
            runtime: string;
            name: string;
            tag: string;
            resources?: undefined;
            env?: undefined;
            command?: undefined;
            files?: undefined;
            path?: undefined;
            recursive?: undefined;
            sizeBytes?: undefined;
            fileCount?: undefined;
        };
        exampleHeaders?: undefined;
    } | {
        id: string;
        title: string;
        sectionTitle: string;
        method: string;
        path: string;
        description: string;
        pathParams: {
            name: string;
            type: string;
            description: string;
            required: boolean;
        }[];
        queryParams: {
            name: string;
            type: string;
            description: string;
            required: boolean;
        }[];
        requestBody: {
            description: string;
            fields: {
                schema: import("zod").ZodObject<{
                    sizeBytes: import("zod").ZodNumber;
                    fileCount: import("zod").ZodNumber;
                    files: import("zod").ZodArray<import("zod").ZodObject<{
                        path: import("zod").ZodString;
                        size: import("zod").ZodNumber;
                        sha256: import("zod").ZodString;
                        contentType: import("zod").ZodString;
                        mode: import("zod").ZodNumber;
                    }, import("zod/v4/core").$strip>>;
                    dependencies: import("zod").ZodOptional<import("zod").ZodArray<import("zod").ZodString>>;
                    packages: import("zod").ZodOptional<import("zod").ZodArray<import("zod").ZodString>>;
                    env: import("zod").ZodOptional<import("zod").ZodRecord<import("zod").ZodString, import("zod").ZodString>>;
                    metadata: import("zod").ZodOptional<import("zod").ZodRecord<import("zod").ZodString, import("zod").ZodString>>;
                }, import("zod/v4/core").$strip>;
                omit?: undefined;
            };
        };
        responseDescription: string;
        statuses: {
            code: number;
            description: string;
        }[];
        examplePath: string;
        exampleBody: {
            sizeBytes: number;
            fileCount: number;
            files: {
                path: string;
                size: number;
            }[];
            name?: undefined;
            runtime?: undefined;
            resources?: undefined;
            env?: undefined;
            command?: undefined;
            path?: undefined;
            recursive?: undefined;
            tag?: undefined;
        };
        responseFields?: undefined;
        exampleHeaders?: undefined;
    } | {
        id: string;
        title: string;
        sectionTitle: string;
        method: string;
        path: string;
        description: string;
        pathParams: {
            name: string;
            type: string;
            description: string;
            required: boolean;
        }[];
        queryParams: {
            name: string;
            type: string;
            description: string;
            required: boolean;
        }[];
        requestBody: {
            description: string;
            fields: {
                schema: import("zod").ZodObject<{
                    sandboxId: import("zod").ZodString;
                    name: import("zod").ZodString;
                    orgId: import("zod").ZodOptional<import("zod").ZodString>;
                }, import("zod/v4/core").$strip>;
                omit: string[];
            };
        };
        responseDescription: string;
        responseFields: {
            schema: import("zod").ZodObject<{
                id: import("zod").ZodString;
                name: import("zod").ZodString;
                createdAt: import("zod").ZodString;
                parent: import("zod").ZodString;
            }, import("zod/v4/core").$strip>;
            stripRequired?: undefined;
        };
        statuses: {
            code: number;
            description: string;
        }[];
        examplePath: string;
        exampleBody: {
            name: string;
            runtime?: undefined;
            resources?: undefined;
            env?: undefined;
            command?: undefined;
            files?: undefined;
            path?: undefined;
            recursive?: undefined;
            tag?: undefined;
            sizeBytes?: undefined;
            fileCount?: undefined;
        };
        exampleHeaders?: undefined;
    } | {
        id: string;
        title: string;
        sectionTitle: string;
        method: string;
        path: string;
        description: string;
        pathParams: never[];
        queryParams: {
            name: string;
            type: string;
            description: string;
            required: boolean;
        }[];
        requestBody: null;
        responseDescription: string;
        responseFields: {
            schema: import("zod").ZodDiscriminatedUnion<[import("zod").ZodObject<{
                success: import("zod").ZodLiteral<false>;
                message: import("zod").ZodString;
                code: import("zod").ZodOptional<import("zod").ZodString>;
            }, import("zod/v4/core").$strip>, import("zod").ZodObject<{
                success: import("zod").ZodLiteral<true>;
                data: import("zod").ZodObject<{
                    runtimes: import("zod").ZodArray<import("zod").ZodObject<{
                        id: import("zod").ZodString;
                        name: import("zod").ZodString;
                        description: import("zod").ZodOptional<import("zod").ZodString>;
                        iconUrl: import("zod").ZodOptional<import("zod").ZodString>;
                        brandColor: import("zod").ZodOptional<import("zod").ZodString>;
                        url: import("zod").ZodOptional<import("zod").ZodString>;
                        tags: import("zod").ZodOptional<import("zod").ZodArray<import("zod").ZodString>>;
                        requirements: import("zod").ZodOptional<import("zod").ZodObject<{
                            memory: import("zod").ZodOptional<import("zod").ZodString>;
                            cpu: import("zod").ZodOptional<import("zod").ZodString>;
                            disk: import("zod").ZodOptional<import("zod").ZodString>;
                            networkEnabled: import("zod").ZodBoolean;
                        }, import("zod/v4/core").$strip>>;
                        readme: import("zod").ZodOptional<import("zod").ZodString>;
                    }, import("zod/v4/core").$strip>>;
                    total: import("zod").ZodNumber;
                }, import("zod/v4/core").$strip>;
            }, import("zod/v4/core").$strip>], "success">;
            stripRequired?: undefined;
        };
        statuses: {
            code: number;
            description: string;
        }[];
        examplePath: string;
        exampleBody?: undefined;
        exampleHeaders?: undefined;
    } | {
        id: string;
        title: string;
        sectionTitle: string;
        method: string;
        path: string;
        description: string;
        pathParams: {
            name: string;
            type: string;
            description: string;
            required: boolean;
        }[];
        queryParams: never[];
        requestBody: null;
        responseDescription: string;
        responseFields: {
            schema: import("zod").ZodObject<{
                id: import("zod").ZodString;
                name: import("zod").ZodNullable<import("zod").ZodString>;
                region: import("zod").ZodString;
                status: import("zod").ZodString;
                orgId: import("zod").ZodString;
                projectId: import("zod").ZodNullable<import("zod").ZodString>;
            }, import("zod/v4/core").$strip>;
            stripRequired?: undefined;
        };
        statuses: {
            code: number;
            description: string;
        }[];
        examplePath: string;
        exampleBody?: undefined;
        exampleHeaders?: undefined;
    })[];
};
export default service;
//# sourceMappingURL=api-reference.d.ts.map